# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


class FlaskApplication:
    def __init__(self, app, host, port, debug, **options):
        self.app = app
        self.host = host
        self.port = port
        self.debug = debug
        self.options = options

    def run(self):
        self.app.run(self.host, self.port, debug=self.debug, **self.options)
